
# THIS FILE IS GENERATED FROM NUMPY SETUP.PY
#
# To compare versions robustly, use `numpy.lib.NumpyVersion`
short_version = '1.14.5'
version = '1.14.5'
full_version = '1.14.5'
git_revision = '3e8744cff9f5686cdbe639821fce1af130c6a14e'
release = True

if not release:
    version = full_version
